@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 Templin Konstantin
+# Copyright (c) 2021-2022 Templin Konstantin
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,13 +21,19 @@
 # SOFTWARE.
 
 import os
-from os.path import abspath, dirname
+from os.path import abspath
+from os.path import dirname
+
 
 __version__ = "0.1.0"
-__feijoa_folder__ = os.path.join(dirname(abspath(__file__)))
-__project_folder__ = dirname(__feijoa_folder__)
+__feijoa_folder__: str = os.path.join(dirname(abspath(__file__)))
+__project_folder__: str = dirname(__feijoa_folder__)
 
-from .jobs import create_job, load_job
+from .jobs.job import create_job
+from .jobs.job import load_job
 from .models import Experiment
-from .search import Categorical, Integer, Real, SearchSpace
+from .search.parameters import Categorical
+from .search.parameters import Integer
+from .search.parameters import Real
+from .search.space import SearchSpace
 from .storages import Storage
