@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 Templin Konstantin
+# Copyright (c) 2021-2022 Templin Konstantin
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -19,14 +19,25 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
+"""Parameters module."""
+
 import abc
 
-__all__ = ["Parameter", "Integer", "Real", "Categorical", "ParametersVisitor"]
+
+__all__ = [
+    "Parameter",
+    "Integer",
+    "Real",
+    "Categorical",
+    "ParametersVisitor",
+]
 
 from feijoa.exceptions import ParametersIncorrectInputValues
 
 
 class Parameter(metaclass=abc.ABCMeta):
+    """Base class of parameter."""
+
     def __init__(self, name: str):
         self.name = name
 
@@ -38,43 +49,105 @@ class Parameter(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def accept(self, v):
+        """
+        Accept visitor.
+
+        Args:
+            v (Visitor):
+                ParametersVisitor instance.
+
+        Returns:
+            Any
+
+        """
+
         raise NotImplementedError()
 
     @abc.abstractmethod
     def seed(self):
+        """Make some legal value."""
+
         raise NotImplementedError()
 
     @abc.abstractmethod
     def is_primitive(self):
+        """Primitive parameter, such as integer, real."""
+
         raise NotImplementedError()
 
     @abc.abstractmethod
     def get_unit_value(self, value):
+        """Only for primitive parameters."""
+
         raise NotImplementedError()
 
     @property
     @abc.abstractmethod
     def meta(self):
+        """Meta information of parameter."""
+
         raise NotImplementedError()
 
 
 class Integer(Parameter):
+    """
+    Integer parameter class.
+
+    Represents discrete integer parameters from Z-space.
+
+    Such parameters can be, for example, the number of
+    layers in neural networks or the number of neurons
+    in a hidden layer, max depth of tree.
+
+    Example:
+
+    .. code-block:: python
+
+        from feijoa.search.parameters import Integer
+
+        param = Integer("foo", low=0, high=10)
+
+    .. note:
+        In parameters creation strict-typing is used
+        for input values.
+
+    Args:
+        name (str):
+            Name of parameter.
+        low (int):
+            Lower bound of parameter.
+        high (int):
+            Upper bound of parameter.
+
+    Raises:
+        ParametersIncorrectInputValues:
+            If input values is not valid integer values.
+        AnyError:
+            If anything bad happens.
+
+    """
+
     def __init__(self, name: str, *, low: int, high: int):
         super().__init__(name)
 
         if not isinstance(low, int) or not isinstance(high, int):
-            raise ParametersIncorrectInputValues("Low and High bounds for"
-                                                 " Integer parameter"
-                                                 " must be ints.")
+            raise ParametersIncorrectInputValues(
+                "Low and High bounds for"
+                " Integer parameter"
+                " must be ints."
+            )
         if low > high:
-            raise ParametersIncorrectInputValues("High bound must"
-                                                 " be greater than low bound.")
+            raise ParametersIncorrectInputValues(
+                "High bound must" " be greater than low bound."
+            )
 
         self.low = low
         self.high = high
 
     def __repr__(self):
-        return f"Integer('{self.name}, low={self.low}, high={self.high})"
+        return (
+            f"Integer('{self.name}, low={self.low}, high={self.high})"
+        )
 
     def accept(self, v):
         return v.visit_integer(self)
@@ -86,37 +159,79 @@ class Integer(Parameter):
         return True
 
     def get_unit_value(self, value):
-        return float(value -
-                     (self.low - 0.4999)) / float((self.high + 0.4999) -
-                                                  (self.low - 0.4999))
+        return float(value - (self.low - 0.4999)) / float(
+            (self.high + 0.4999) - (self.low - 0.4999)
+        )
 
     @property
     def meta(self):
         m = {
-            'low': self.low,
-            'high': self.high,
+            "low": self.low,
+            "high": self.high,
         }
         return m
 
 
 class Real(Parameter):
+    """
+    Real parameter class.
+
+    Represents real parameters from R-space.
+
+    Such parameters can be, for example, learning
+    rate of ML oracle, or mutation rate in
+    genetic oracles.
+
+    Example:
+
+    .. code-block:: python
+
+        from feijoa.search.parameters import Real
+
+        param = Real("foo", low=0.0, high=10.0)
+
+    Args:
+        name (str):
+            Name of parameter.
+        low (float):
+            Lower bound of parameter.
+        high (float):
+            Upper bound of parameter.
+
+    .. note:
+        In parameters creation strict-typing is used
+        for input values.
+
+    Raises:
+        ParametersIncorrectInputValues:
+            If input values is not valid real values.
+        AnyError:
+            If anything bad happens.
+
+    """
+
     def __init__(self, name: str, *, low: float, high: float):
         super().__init__(name)
 
         if not isinstance(low, float) or not isinstance(high, float):
-            raise ParametersIncorrectInputValues("Low and High bounds for"
-                                                 " Float parameter"
-                                                 " must be floats.")
+            raise ParametersIncorrectInputValues(
+                "Low and High bounds for"
+                " Float parameter"
+                " must be floats."
+            )
 
         if low > high:
-            raise ParametersIncorrectInputValues("High bound must"
-                                                 " be greater than low bound.")
+            raise ParametersIncorrectInputValues(
+                "High bound must" " be greater than low bound."
+            )
 
         self.low = low
         self.high = high
 
     def __repr__(self):
-        return f"Real('{self.name}', {self.low=}, {self.high=})"
+        return (
+            f"Real('{self.name}', low={self.low}, high={self.high})"
+        )
 
     def accept(self, v):
         return v.visit_real(self)
@@ -133,23 +248,52 @@ class Real(Parameter):
     @property
     def meta(self):
         m = {
-            'low': self.low,
-            'high': self.high,
+            "low": self.low,
+            "high": self.high,
         }
         return m
 
 
 class Categorical(Parameter):
+    """
+    Categorical parameter class.
+
+    Represents category parameters.
+
+    Such parameters can be, activation function,
+    or type of regression model in AutoML.
+
+    Args:
+        name (str):
+            Name of parameter.
+        choices (list):
+            List of choices, for example: ```['rbf', 'sigmoid']```
+
+    .. note:
+        In parameters creation strict-typing is used
+        for input values.
+
+    Raises:
+        ParametersIncorrectInputValues:
+            If input values is empty or exists
+            not unique values.
+        AnyError:
+            If anything bad happens.
+
+    """
+
     def __init__(self, name: str, *, choices):
         super().__init__(name)
 
         if not choices:
             raise ParametersIncorrectInputValues(
                 "Choices for Categorical"
-                " parameter must be not empty.")
+                " parameter must be not empty."
+            )
         if len(choices) != len(set(choices)):
-            raise ParametersIncorrectInputValues("Choices for Categorical"
-                                                 " parameter must unique.")
+            raise ParametersIncorrectInputValues(
+                "Choices for Categorical" " parameter must unique."
+            )
         self.choices = choices
 
     def __repr__(self):
@@ -169,21 +313,37 @@ class Categorical(Parameter):
 
     @property
     def meta(self):
-        m = {
-            'choices': self.choices
-        }
+        m = {"choices": self.choices}
         return m
 
 
 class ParametersVisitor(metaclass=abc.ABCMeta):
+    """
+    Parameters abstract visitor
+
+        Used for iteration over collections
+        with parameters.
+
+        Raises:
+            AnyError:
+                If anything bad happens.
+
+    """
+
     @abc.abstractmethod
     def visit_integer(self, p: Integer):
+        """Visit integer parameter."""
+
         raise NotImplementedError()
 
     @abc.abstractmethod
     def visit_real(self, p: Real):
+        """Visit real parameter."""
+
         raise NotImplementedError()
 
     @abc.abstractmethod
     def visit_categorical(self, p: Categorical):
+        """Visit categorical parameter."""
+
         raise NotImplementedError()
