@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 Templin Konstantin
+# Copyright (c) 2021-2022 Templin Konstantin
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -19,35 +19,71 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-import warnings
+"""Search space module."""
+
 from typing import List
+import warnings
 
 import yaml
 
-from feijoa.search.parameters import Categorical, Integer, Parameter, Real
+from feijoa.search.parameters import Categorical
+from feijoa.search.parameters import Integer
+from feijoa.search.parameters import Parameter
+from feijoa.search.parameters import Real
+
 
 __all__ = ["SearchSpace"]
 
 
 class SearchSpace:
-    """Search (observation) space class"""
+    """
+    Search space class.
+
+    Represents cartesian multiplication of
+    set of available values for every
+    parameter.
+
+    Example:
+
+        .. code-block:: python
+
+            from feijoa.search.space import SearchSpace
+            from feijoa.search.parameters import Real
+
+            space = SearchSpace()
+            space.insert(Real("x", low=0.0, high=1.0))
+
+    Args:
+        parameters (list, optional):
+            List of parameters instances.
+
+
+    Raises:
+        AnyError: If anything bad happens.
+
+    """
+
     def __init__(self, *parameters):
         self.params: List[Parameter] = parameters or list()
         self.name2param = {p.name: p for p in parameters} or dict()
 
     def insert(self, p: Parameter) -> None:
+        """Insert parameter into search space"""
+
         # TODO (qnbhd): make duplication check
         self.params.append(p)
         self.name2param[p.name] = p
 
     def get(self, item: str, default=None):
+        """Get parameters by name from search space."""
+
         return self.name2param.get(item, default)
 
     def __repr__(self) -> str:
         buff = ["SearchSpace:"]
 
         for p in self.params:
-            buff.append(f"\t{p}")
+            buff.append(f"{' ' * 4}{p}")
 
         return "\n".join(buff)
 
@@ -62,7 +98,7 @@ class SearchSpace:
 
     @classmethod
     def from_yaml(cls, yaml_string):
-        """Load search space from yaml file."""
+        """Load search space from yaml."""
 
         space_dumped = yaml.safe_load(yaml_string)
 
@@ -76,11 +112,22 @@ class SearchSpace:
 
     @classmethod
     def from_yaml_file(cls, yaml_file):
+        """Load search space from yaml file."""
+
         with open(yaml_file) as f:
             return cls.from_yaml(f.read())
 
     @classmethod
     def from_db_parameters(cls, parameters):
+        """
+        Build search space from db representation
+                of parameters.
+
+                Raises:
+                    AnyError: If anything bad happens.
+
+        """
+
         pool = list()
 
         for param in parameters:
@@ -88,8 +135,8 @@ class SearchSpace:
             kind = param.kind
             meta = param.meta
             kwargs = {
-                'signature': name,
-                'type': kind,
+                "signature": name,
+                "type": kind,
                 **meta,
             }
             p = parameter_factory(**kwargs)
@@ -99,6 +146,21 @@ class SearchSpace:
 
 
 def parameter_factory(**kwargs):
+    """
+    Create parameters from dict representation.
+
+        Args:
+            kwargs (Dict[str]):
+                Dict with information about parameter.
+
+        Returns:
+            Parameter builded from kwargs.
+
+        Raises:
+            AnyError: If anything bad happens.
+
+    """
+
     param_signature = kwargs["signature"]
 
     if kwargs["type"] in ("integer", "Integer"):
@@ -122,7 +184,8 @@ def parameter_factory(**kwargs):
 
 
 def from_yaml(yaml_file: str) -> SearchSpace:
-    """Load search space from yaml file."""
+    """
+    Load search space from yaml file."""
 
     warnings.warn(
         "Function `from_yaml` is deprecated."
