@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 Templin Konstantin
+# Copyright (c) 2021-2022 Templin Konstantin
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,10 +20,12 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 import abc
-from typing import List, Optional
+from typing import List
+from typing import Optional
 
-from feijoa.search.space import SearchSpace
 from feijoa.models import Experiment
+from feijoa.search.space import SearchSpace
+
 
 __all__ = ["Storage"]
 
@@ -31,9 +33,15 @@ __all__ = ["Storage"]
 class Storage(metaclass=abc.ABCMeta):
     def insert_job(self, job):
         """
+        Insert job into storage.
+
+        Args:
+            job (Job):
+                Job instance.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param job:
-        :return:
         """
 
         raise NotImplementedError()
@@ -41,9 +49,15 @@ class Storage(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def is_job_name_exists(self, name):
         """
+        Find job in storage.
+
+        Args:
+            name (str):
+                Job name.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param name:
-        :return:
         """
 
         raise NotImplementedError()
@@ -51,9 +65,15 @@ class Storage(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def get_job_id_by_name(self, name) -> Optional[int]:
         """
+        Get job by id in storage.
+
+        Args:
+            name (str):
+                Name of job.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param name:
-        :return:
         """
 
         raise NotImplementedError()
@@ -61,9 +81,15 @@ class Storage(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def insert_experiment(self, experiment):
         """
+        Insert experiment into storage.
+
+        Args:
+            experiment (Experiment):
+                Experiment instance to insert.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param experiment:
-        :return:
         """
 
         raise NotImplementedError()
@@ -71,10 +97,17 @@ class Storage(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def get_experiment(self, job_id, experiment_id):
         """
+        Get experiment from job.
+
+        Args:
+            job_id (int):
+                Job index.
+            experiment_id (int):
+                Experiment index.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param job_id:
-        :param experiment_id:
-        :return:
         """
 
         raise NotImplementedError()
@@ -82,28 +115,46 @@ class Storage(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def get_experiments_by_job_id(self, job_id) -> List[Experiment]:
         """
+        Get experiments from job
+
+        Args:
+            job_id:
+                Index of job in storage.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param job_id:
-        :return:
         """
 
         raise NotImplementedError()
 
     @abc.abstractmethod
-    def get_experiments_count(self, job) -> int:
+    def get_experiments_count(self, job_id) -> int:
         """
+        Get experiments count in specified job.
+
+        Args:
+            job_id (int):
+                Job id.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param job:
-        :return:
         """
 
         pass
 
     def best_experiment(self, job) -> Optional[Experiment]:
         """
+        Get best experiment from job.
+
+        Args:
+            job (Job):
+                Job instance.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param job:
-        :return:
         """
 
         experiments = self.get_experiments_by_job_id(job)
@@ -111,25 +162,38 @@ class Storage(metaclass=abc.ABCMeta):
         if not experiments:
             return None
 
-        return min(experiments, key=lambda x: x.objective_result)
+        return min(experiments, key=lambda x: x.objective_result)  # type: ignore
 
     def top_experiments(self, job_id, n) -> List[Experiment]:
         """
+        Get top experiments from job.
+        Experiments is sorted by objective values.
+
+        Args:
+            job_id (int):
+                Job index.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param job_id:
-        :param n:
-        :return:
         """
 
         experiments = self.get_experiments_by_job_id(job_id)
 
-        experiments.sort(key=lambda x: x.objective_result)
-        return experiments[:min(len(experiments), n)]
+        experiments.sort(key=lambda x: x.objective_result)  # type: ignore
+        return experiments[: min(len(experiments), n)]
 
     def get_search_space_by_job_id(self, job_id) -> SearchSpace:
         """
+        Get search space from existed job.
+
+        Args:
+            job_id (int):
+                Job index.
+
+        Raises:
+            AnyError: If anything bad happens.
 
-        :param job_id:
         """
 
         raise NotImplementedError()
@@ -137,13 +201,19 @@ class Storage(metaclass=abc.ABCMeta):
     @property
     @abc.abstractmethod
     def jobs(self):
+        """Pick up jobs from storage."""
+
         raise NotImplementedError()
 
     @property
     def jobs_count(self):
+        """Get jobs count from storage."""
+
         return len(self.jobs)
 
     @property
     @abc.abstractmethod
     def version(self):
+        """Get version of database schema."""
+
         raise NotImplementedError()
