@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 Templin Konstantin
+# Copyright (c) 2021-2022 Templin Konstantin
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -27,6 +27,18 @@ from rich.traceback import install
 
 
 def init(verbose=False):
+    """
+    Init logging.
+
+        Args:
+            verbose (bool):
+                Verbose level (DEBUG) or not (INFO).
+
+        Raises:
+            AnyError: If anything bad happens.
+
+    """
+
     install(suppress=[click])
 
     logging.basicConfig(
@@ -34,10 +46,20 @@ def init(verbose=False):
         format="%(message)s",
         datefmt="[%X]",
         handlers=[
-            RichHandler(rich_tracebacks=True,
-                        markup=True,
-                        enable_link_path=False)
+            RichHandler(
+                rich_tracebacks=True,
+                markup=True,
+                enable_link_path=False,
+            )
         ],
     )
 
-    logging.getLogger("executor").setLevel(logging.CRITICAL)
+    excluded_loggers = (
+        "numba",
+        "matplotlib",
+        "executor",
+    )
+
+    for log_name in excluded_loggers:
+        other_log = logging.getLogger(log_name)
+        other_log.setLevel(logging.WARNING)
